Welcome to the earthkit-maps documentation
======================================================

.. warning::

    This project is **BETA** and will be **Experimental** for the foreseeable future. Interfaces and functionality are likely to change, and the project itself may be scrapped. **DO NOT** use this software in any project/software that is operational.

.. warning::

    This documentation is still work in progress and can only be regarded as a **DRAFT**.
